<!-- draft-otis-newtrk-rfc-set-02 
	 srd XSLT transformation to HTML
  -->
<!-- Copyright © The Internet Society (2005). 
	 This document is subject to the rights, licenses and
   restrictions contained in BCP 78.
  -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  version="1.0">
  <xsl:output method="html"/>
  <!--style similar to rfc2629.xslt by Julian F. Reschke  -->
  <xsl:template name="srd-style">
    body {color: #000000; font-family: helvetica, arial, 
          sans-serif; font-size: 12pt;}
    h1 {color: #333333; font-size: 14pt; line-height: 21pt;
        font-family: helvetica, arial, sans-serif;
        page-break-after: avoid;}
    h2 {color: #000000; font-size: 12pt; line-height: 15pt;
        font-family: helvetica, arial, sans-serif; 
        page-break-after: avoid;}
    p {margin-left: 2em; margin-right: 2em;} 
    .error {font-size: 14pt; background-color: red;} 
    .title {color: #990000; font-size: 18pt; line-height: 18pt;
            font-weight: bold; text-align: left;}
    .filename {color: #333333; font-weight: bold; font-size: 12pt;
               line-height: 21pt; text-align: left;}
  </xsl:template>
  <!-- url prefix for references -->
  <xsl:param name="url-prefix-rfc"
    select="'http://www.ietf.org/rfc/rfc'"/>
  <xsl:param name="url-prefix-i-d"
    select="'http://www.ietf.org/internet-drafts/draft-'"/>
  <xsl:param name="url-prefix-srd"
    select="'http://www.ietf.org/srd/srd-'"/>
  <xsl:param name="url-prefix-errata"
    select="'http://www.rfc-editor.org/cgi-bin/errata.pl#rfc'"/>
  <!-- path for xml references -->
  <xsl:param name="xml-refs-rfc"
    select="'references/rfc/reference.RFC.'"/>
  <xsl:param name="xml-refs-i-d"
    select="'references/i-d/reference.I-D.'"/>
  <xsl:param name="xml-refs-srd"
    select="'references/srd/reference.SRD.'"/>
  <!-- page title -->
  <xsl:param name="srd-title" select="normalize-space(/srd/title)"/>
  <!-- set name elements -->
  <xsl:param name="srd-set" select="normalize-space(/srd/@set)"/>
  <xsl:param name="srd-wip" select="normalize-space(/srd/@wip)"/>
  <!-- set wip name -->
  <xsl:param name="srd-wip-name" select="concat('X', $srd-wip,
    '-',   $srd-set)"/>
  <xsl:param name="srd-date" select="normalize-space(/srd/srdDate)"/>
  <!-- PI delimiters -->
  <xsl:variable name="pi-delim">"'</xsl:variable>
  <!-- p i for sorting <?srd sortrefs ="yes" ?> -->
  <xsl:param name="sort-refs" select="substring-after(
    translate(/processing-instruction('srd')
    [contains(.,'sortrefs=')],
    concat($pi-delim,' '), ''), 'sortrefs=')"/>
  <!-- p i for strict <?srd strict ="yes" ?> -->
  <xsl:param name="srd-strict" select="substring-after(
    translate(/processing-instruction('srd')[contains(.,'strict=')],
    concat($pi-delim,' '), ''), 'strict=')"/>
  <!-- Template for root element -->
  <xsl:template match="srd">
    <html lang="en">
      <head>
        <title>
          <xsl:value-of select="$srd-title"/>
        </title>
        <style type="text/css" title="srd style">
          <xsl:call-template name="srd-style"/>
        </style>
      </head>
      <body>
        <h1 class="title">
          <xsl:if test="$srd-wip=''">
            <xsl:value-of select="$srd-title"
              /><br/>SRD:[<xsl:value-of
              select="concat($srd-set,']&#160;',$srd-date)"/>
          </xsl:if>
          <xsl:if test="$srd-wip!=''">
            <xsl:value-of select="$srd-title"
              /><br/>SRD:[<xsl:value-of
              select="concat($srd-wip-name,']&#160;',$srd-date)"
            />
          </xsl:if>
        </h1>
        <h2>
          <xsl:value-of select="normalize-space(/srd/description)"/>
        </h2>
        <xsl:if test="$sort-refs='yes'">
          <!-- sorted references -->
          <xsl:call-template name="core"/>
          <xsl:for-each select="/srd/core/srdref">
            <xsl:sort select="@dt" data-type="text"
              order="descending"/>
            <xsl:sort select="@dd" data-type="text"
              order="ascending"/>
            <xsl:call-template name="srdref"/>
          </xsl:for-each>
          <xsl:if test="/srd/extensions">
            <xsl:call-template name="extensions"/>
            <xsl:for-each select="/srd/extensions/srdref">
              <xsl:sort select="@dt" data-type="text"
                order="descending"/>
              <xsl:sort select="@dd" data-type="text"
                order="ascending"/>
              <xsl:call-template name="srdref"/>
            </xsl:for-each>
          </xsl:if>
          <xsl:if test="/srd/guidance">
            <xsl:call-template name="guidance"/>
            <xsl:for-each select="/srd/guidance/srdref">
              <xsl:sort select="@dt" data-type="text"
                order="descending"/>
              <xsl:sort select="@dd" data-type="text"
                order="ascending"/>
              <xsl:call-template name="srdref"/>
            </xsl:for-each>
          </xsl:if>
          <xsl:if test="/srd/replaces">
            <xsl:call-template name="replaces"/>
            <xsl:for-each select="/srd/replaces/srdref">
              <xsl:sort select="@dt" data-type="text"
                order="descending"/>
              <xsl:sort select="@dd" data-type="text"
                order="ascending"/>
              <xsl:call-template name="srdref"/>
            </xsl:for-each>
          </xsl:if>
          <xsl:if test="/srd/experimental">
            <xsl:call-template name="experimental"/>
            <xsl:for-each select="/srd/experimental/srdref">
              <xsl:sort select="@dt" data-type="text"
                order="descending"/>
              <xsl:sort select="@dd" data-type="text"
                order="ascending"/>
              <xsl:call-template name="srdref"/>
            </xsl:for-each>
          </xsl:if>
          <xsl:if test="/srd/companion">
            <xsl:call-template name="companion"/>
            <xsl:for-each select="/srd/companion/srdref">
              <xsl:sort select="@dt" data-type="text"
                order="descending"/>
              <xsl:sort select="@dd" data-type="text"
                order="ascending"/>
              <xsl:call-template name="srdref"/>
            </xsl:for-each>
          </xsl:if>
        </xsl:if>
        <xsl:if test="$sort-refs!='yes'">
          <!-- unsorted references -->
          <xsl:call-template name="core"/>
          <xsl:for-each select="/srd/core/srdref">
            <xsl:call-template name="srdref"/>
          </xsl:for-each>
          <xsl:if test="/srd/extensions">
            <xsl:call-template name="extensions"/>
            <xsl:for-each select="/srd/extensions/srdref">
              <xsl:call-template name="srdref"/>
            </xsl:for-each>
          </xsl:if>
          <xsl:if test="/srd/guidance">
            <xsl:call-template name="guidance"/>
            <xsl:for-each select="/srd/guidance/srdref">
              <xsl:call-template name="srdref"/>
            </xsl:for-each>
          </xsl:if>
          <xsl:if test="/srd/replaces">
            <xsl:call-template name="replaces"/>
            <xsl:for-each select="/srd/replaces/srdref">
              <xsl:call-template name="srdref"/>
            </xsl:for-each>
          </xsl:if>
          <xsl:if test="/srd/experimental">
            <xsl:call-template name="experimental"/>
            <xsl:for-each select="/srd/experimental/srdref">
              <xsl:call-template name="srdref"/>
            </xsl:for-each>
          </xsl:if>
          <xsl:if test="/srd/companion">
            <xsl:call-template name="companion"/>
            <xsl:for-each select="/srd/companion/srdref">
              <xsl:call-template name="srdref"/>
            </xsl:for-each>
          </xsl:if>
        </xsl:if>
      </body>
    </html>
  </xsl:template>
  <xsl:template name="core">
    <h2>Core</h2>
  </xsl:template>
  <xsl:template name="extensions">
    <h2>Extensions</h2>
  </xsl:template>
  <xsl:template name="guidance">
    <h2>Guidance</h2>
  </xsl:template>
  <xsl:template name="replaces">
    <h2>Replaces</h2>
  </xsl:template>
  <xsl:template name="experimental">
    <h2>Experimental</h2>
  </xsl:template>
  <xsl:template name="companion">
    <h2>Companion</h2>
  </xsl:template>
  <xsl:template name="srdref">
    <xsl:variable name="d-type" select="normalize-space(@dt)"/>
    <xsl:variable name="d-des" select="normalize-space(@dd)"/>
    <xsl:variable name="rfc-ref" select="concat($xml-refs-rfc,
      @dd, '.xml')"/>
    <xsl:variable name="i-d-ref" select="concat($xml-refs-i-d,
      @dd, '.xml')"/>
    <xsl:variable name="srd-ref" select="concat($xml-refs-srd,
      @dd, '.xml')"/>
    <xsl:choose>
      <xsl:when test="$d-type='RFC'">
        <a class="filename" href="{concat($url-prefix-rfc,
          $d-des,'.txt')}">[<xsl:value-of select="$d-type"
            /><xsl:value-of select="$d-des"/>]</a>
        <xsl:text>&#160;</xsl:text>
        <a class="filename" href="{concat($url-prefix-errata,
          $d-des)}">errata</a>
        <xsl:text>&#160;</xsl:text>
        <xsl:if test="document($rfc-ref)//front/title and
          document($rfc-ref)//format/@target">
          <a class="filename"
            href="{document($rfc-ref)//format/@target}">
            <xsl:value-of select="document($rfc-ref)//front/title"/>
          </a>
        </xsl:if>
      </xsl:when>
      <xsl:when test="$d-type='SRD'">
        <a class="filename" href="{concat($url-prefix-srd,
          $d-des,'.html')}">[<xsl:value-of select="$d-type"
            /><xsl:value-of select="$d-des"/>]</a>
        <xsl:text>&#160;</xsl:text>
        <xsl:if test="document($srd-ref)//front/title and
          document($srd-ref)//format/@target">
          <a class="filename"
            href="{document($srd-ref)//format/@target}">
            <xsl:value-of select="document($srd-ref)//front/title"/>
          </a>
        </xsl:if>
      </xsl:when>
      <xsl:when test="$d-type='I-D' and $srd-wip!=''">
        <xsl:value-of select="concat('[draft-',$d-des, ']')"/>
        <xsl:text>&#160;</xsl:text>
        <xsl:if test="document($i-d-ref)//front/title and
          document($i-d-ref)//format/@target">
          <a class="filename"
            href="{document($i-d-ref)//format/@target}">
            <xsl:value-of select="document($i-d-ref)//front/title"/>
          </a>
        </xsl:if>
      </xsl:when>
      <xsl:when test="$d-type='I-D' and $srd-wip='' and
        $srd-strict!='yes'">
        <xsl:value-of select="concat('[draft-',$d-des, ']')"/>
        <xsl:text>&#160;</xsl:text>
        <xsl:if test="document($i-d-ref)//front/title and
          document($i-d-ref)//format/@target">
          <a class="filename"
            href="{document($i-d-ref)//format/@target}">
            <xsl:value-of select="document($i-d-ref)//front/title"/>
          </a>
        </xsl:if>
      </xsl:when>
      <xsl:otherwise>
        <p class="error">Invalid Document Type [<xsl:value-of
            select="@dt"/>]<xsl:value-of select="@dd"/></p>
      </xsl:otherwise>
    </xsl:choose>
    <br/>
  </xsl:template>
</xsl:stylesheet>
